# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from google_drive_ti.models.content_restriction import ContentRestriction
from google_drive_ti.models.file_capabilities import FileCapabilities
from google_drive_ti.models.file_content_hints import FileContentHints
from google_drive_ti.models.file_image_media_metadata import FileImageMediaMetadata
from google_drive_ti.models.file_label_info import FileLabelInfo
from google_drive_ti.models.file_link_share_metadata import FileLinkShareMetadata
from google_drive_ti.models.file_shortcut_details import FileShortcutDetails
from google_drive_ti.models.file_video_media_metadata import FileVideoMediaMetadata
from google_drive_ti.models.permission import Permission
from google_drive_ti.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class File(BaseModel):
    """
    The metadata for a file. Some resource methods (such as `files.update`) require a `fileId`. Use the `files.list` method to retrieve the ID for a file.
    """ # noqa: E501
    app_properties: Optional[Dict[str, Any]] = Field(default=None, description="A collection of arbitrary key-value pairs which are private to the requesting app. Entries with null values are cleared in update and copy requests. These properties can only be retrieved using an authenticated request. An authenticated request uses an access token obtained with a OAuth 2 client ID. You cannot use an API key to retrieve private properties.", alias="appProperties")
    capabilities: Optional[FileCapabilities] = None
    content_hints: Optional[FileContentHints] = Field(default=None, alias="contentHints")
    content_restrictions: Optional[List[ContentRestriction]] = Field(default=None, description="Restrictions for accessing the content of the file. Only populated if such a restriction exists.", alias="contentRestrictions")
    copy_requires_writer_permission: Optional[StrictBool] = Field(default=None, description="Whether the options to copy, print, or download this file, should be disabled for readers and commenters.", alias="copyRequiresWriterPermission")
    created_time: Optional[datetime] = Field(default=None, description="The time at which the file was created (RFC 3339 date-time).", alias="createdTime")
    description: Optional[StrictStr] = Field(default=None, description="A short description of the file.")
    drive_id: Optional[StrictStr] = Field(default=None, description="Output only. ID of the shared drive the file resides in. Only populated for items in shared drives.", alias="driveId")
    explicitly_trashed: Optional[StrictBool] = Field(default=None, description="Output only. Whether the file has been explicitly trashed, as opposed to recursively trashed from a parent folder.", alias="explicitlyTrashed")
    export_links: Optional[Dict[str, Any]] = Field(default=None, description="Output only. Links for exporting Docs Editors files to specific formats.", alias="exportLinks")
    file_extension: Optional[StrictStr] = Field(default=None, description="Output only. The final component of `fullFileExtension`. This is only available for files with binary content in Google Drive.", alias="fileExtension")
    folder_color_rgb: Optional[StrictStr] = Field(default=None, description="The color for a folder or a shortcut to a folder as an RGB hex string. The supported colors are published in the `folderColorPalette` field of the About resource. If an unsupported color is specified, the closest color in the palette is used instead.", alias="folderColorRgb")
    full_file_extension: Optional[StrictStr] = Field(default=None, description="Output only. The full file extension extracted from the `name` field. May contain multiple concatenated extensions, such as \"tar.gz\". This is only available for files with binary content in Google Drive. This is automatically updated when the `name` field changes, however it is not cleared if the new name does not contain a valid extension.", alias="fullFileExtension")
    has_augmented_permissions: Optional[StrictBool] = Field(default=None, description="Output only. Whether there are permissions directly on this file. This field is only populated for items in shared drives.", alias="hasAugmentedPermissions")
    has_thumbnail: Optional[StrictBool] = Field(default=None, description="Output only. Whether this file has a thumbnail. This does not indicate whether the requesting app has access to the thumbnail. To check access, look for the presence of the thumbnailLink field.", alias="hasThumbnail")
    head_revision_id: Optional[StrictStr] = Field(default=None, description="Output only. The ID of the file's head revision. This is currently only available for files with binary content in Google Drive.", alias="headRevisionId")
    icon_link: Optional[StrictStr] = Field(default=None, description="Output only. A static, unauthenticated link to the file's icon.", alias="iconLink")
    id: Optional[StrictStr] = Field(default=None, description="The ID of the file.")
    image_media_metadata: Optional[FileImageMediaMetadata] = Field(default=None, alias="imageMediaMetadata")
    is_app_authorized: Optional[StrictBool] = Field(default=None, description="Output only. Whether the file was created or opened by the requesting app.", alias="isAppAuthorized")
    kind: Optional[StrictStr] = Field(default='drive#file', description="Output only. Identifies what kind of resource this is. Value: the fixed string `\"drive#file\"`.")
    label_info: Optional[FileLabelInfo] = Field(default=None, alias="labelInfo")
    last_modifying_user: Optional[User] = Field(default=None, alias="lastModifyingUser")
    link_share_metadata: Optional[FileLinkShareMetadata] = Field(default=None, alias="linkShareMetadata")
    md5_checksum: Optional[StrictStr] = Field(default=None, description="Output only. The MD5 checksum for the content of the file. This is only applicable to files with binary content in Google Drive.", alias="md5Checksum")
    mime_type: Optional[StrictStr] = Field(default=None, description="The MIME type of the file. Google Drive attempts to automatically detect an appropriate value from uploaded content, if no value is provided. The value cannot be changed unless a new revision is uploaded. If a file is created with a Google Doc MIME type, the uploaded content is imported, if possible. The supported import formats are published in the About resource.", alias="mimeType")
    modified_by_me: Optional[StrictBool] = Field(default=None, description="Output only. Whether the file has been modified by this user.", alias="modifiedByMe")
    modified_by_me_time: Optional[datetime] = Field(default=None, description="The last time the file was modified by the user (RFC 3339 date-time).", alias="modifiedByMeTime")
    modified_time: Optional[datetime] = Field(default=None, description="he last time the file was modified by anyone (RFC 3339 date-time). Note that setting modifiedTime will also update modifiedByMeTime for the user.", alias="modifiedTime")
    name: Optional[StrictStr] = Field(default=None, description="The name of the file. This is not necessarily unique within a folder. Note that for immutable items such as the top level folders of shared drives, My Drive root folder, and Application Data folder the name is constant.")
    original_filename: Optional[StrictStr] = Field(default=None, description="The original filename of the uploaded content if available, or else the original value of the `name` field. This is only available for files with binary content in Google Drive.", alias="originalFilename")
    owned_by_me: Optional[StrictBool] = Field(default=None, description="Output only. Whether the user owns the file. Not populated for items in shared drives.", alias="ownedByMe")
    owners: Optional[List[User]] = Field(default=None, description="Output only. The owner of this file. Only certain legacy files may have more than one owner. This field isn't populated for items in shared drives.")
    parents: Optional[List[StrictStr]] = Field(default=None, description="The ID of the parent folder containing the file. A file can only have one parent folder; specifying multiple parents isn't supported. If not specified as part of a create request, the file is placed directly in the user's My Drive folder. If not specified as part of a copy request, the file inherits any discoverable parent of the source file. Update requests must use the `addParents` and `removeParents` parameters to modify the parents list.")
    permission_ids: Optional[List[StrictStr]] = Field(default=None, description="Output only. List of permission IDs for users with access to this file.", alias="permissionIds")
    permissions: Optional[List[Permission]] = Field(default=None, description="Output only. The full list of permissions for the file. This is only available if the requesting user can share the file. Not populated for items in shared drives.")
    properties: Optional[Dict[str, Any]] = Field(default=None, description="A collection of arbitrary key-value pairs which are visible to all apps. Entries with null values are cleared in update and copy requests.")
    quota_bytes_used: Optional[StrictStr] = Field(default=None, description="Output only. The number of storage quota bytes used by the file. This includes the head revision as well as previous revisions with `keepForever` enabled.", alias="quotaBytesUsed")
    resource_key: Optional[StrictStr] = Field(default=None, description="Output only. A key needed to access the item via a shared link.", alias="resourceKey")
    sha1_checksum: Optional[StrictStr] = Field(default=None, description="Output only. The SHA1 checksum associated with this file, if available. This field is only populated for files with content stored in Google Drive; it is not populated for Docs Editors or shortcut files.", alias="sha1Checksum")
    sha256_checksum: Optional[StrictStr] = Field(default=None, description="Output only. The SHA256 checksum associated with this file, if available. This field is only populated for files with content stored in Google Drive; it is not populated for Docs Editors or shortcut files.", alias="sha256Checksum")
    shared: Optional[StrictBool] = Field(default=None, description="Output only. Whether the file has been shared. Not populated for items in shared drives.")
    shared_with_me_time: Optional[datetime] = Field(default=None, description="The time at which the file was shared with the user, if applicable (RFC 3339 date-time).", alias="sharedWithMeTime")
    sharing_user: Optional[User] = Field(default=None, alias="sharingUser")
    shortcut_details: Optional[FileShortcutDetails] = Field(default=None, alias="shortcutDetails")
    size: Optional[StrictStr] = Field(default=None, description="Output only. Size in bytes of blobs and first party editor files. Won't be populated for files that have no size, like shortcuts and folders.")
    spaces: Optional[List[StrictStr]] = Field(default=None, description="Output only. The list of spaces which contain the file. The currently supported values are 'drive', 'appDataFolder' and 'photos'.")
    starred: Optional[StrictBool] = Field(default=None, description="Whether the user has starred the file.")
    team_drive_id: Optional[StrictStr] = Field(default=None, description="Deprecated: Output only. Use `driveId` instead.", alias="teamDriveId")
    thumbnail_link: Optional[StrictStr] = Field(default=None, description="Output only. A short-lived link to the file's thumbnail, if available. Typically lasts on the order of hours. Not intended for direct usage on web applications due to [Cross-Origin Resource Sharing (CORS)](https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS) policies, consider using a proxy server. Only populated when the requesting app can access the file's content. If the file isn't shared publicly, the URL returned in `Files.thumbnailLink` must be fetched using a credentialed request.", alias="thumbnailLink")
    thumbnail_version: Optional[StrictStr] = Field(default=None, description="Output only. The thumbnail version for use in thumbnail cache invalidation.", alias="thumbnailVersion")
    trashed: Optional[StrictBool] = Field(default=None, description="Whether the file has been trashed, either explicitly or from a trashed parent folder. Only the owner may trash a file, and other users cannot see files in the owner's trash.")
    trashed_time: Optional[datetime] = Field(default=None, description="The time that the item was trashed (RFC 3339 date-time). Only populated for items in shared drives.", alias="trashedTime")
    trashing_user: Optional[User] = Field(default=None, alias="trashingUser")
    version: Optional[StrictStr] = Field(default=None, description="Output only. A monotonically increasing version number for the file. This reflects every change made to the file on the server, even those not visible to the user.")
    video_media_metadata: Optional[FileVideoMediaMetadata] = Field(default=None, alias="videoMediaMetadata")
    viewed_by_me: Optional[StrictBool] = Field(default=None, description="Output only. Whether the file has been viewed by this user.", alias="viewedByMe")
    viewed_by_me_time: Optional[datetime] = Field(default=None, description="The last time the file was viewed by the user (RFC 3339 date-time).", alias="viewedByMeTime")
    viewers_can_copy_content: Optional[StrictBool] = Field(default=None, description="Deprecated: Use `copyRequiresWriterPermission` instead.", alias="viewersCanCopyContent")
    web_content_link: Optional[StrictStr] = Field(default=None, description="Output only. A link for downloading the content of the file in a browser. This is only available for files with binary content in Google Drive.", alias="webContentLink")
    web_view_link: Optional[StrictStr] = Field(default=None, description="Output only. A link for opening the file in a relevant Google editor or viewer in a browser.", alias="webViewLink")
    writers_can_share: Optional[StrictBool] = Field(default=None, description="Whether users with only `writer` permission can modify the file's permissions. Not populated for items in shared drives.", alias="writersCanShare")
    __properties: ClassVar[List[str]] = ["appProperties", "capabilities", "contentHints", "contentRestrictions", "copyRequiresWriterPermission", "createdTime", "description", "driveId", "explicitlyTrashed", "exportLinks", "fileExtension", "folderColorRgb", "fullFileExtension", "hasAugmentedPermissions", "hasThumbnail", "headRevisionId", "iconLink", "id", "imageMediaMetadata", "isAppAuthorized", "kind", "labelInfo", "lastModifyingUser", "linkShareMetadata", "md5Checksum", "mimeType", "modifiedByMe", "modifiedByMeTime", "modifiedTime", "name", "originalFilename", "ownedByMe", "owners", "parents", "permissionIds", "permissions", "properties", "quotaBytesUsed", "resourceKey", "sha1Checksum", "sha256Checksum", "shared", "sharedWithMeTime", "sharingUser", "shortcutDetails", "size", "spaces", "starred", "teamDriveId", "thumbnailLink", "thumbnailVersion", "trashed", "trashedTime", "trashingUser", "version", "videoMediaMetadata", "viewedByMe", "viewedByMeTime", "viewersCanCopyContent", "webContentLink", "webViewLink", "writersCanShare"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of File from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "export_links",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of capabilities
        if self.capabilities:
            _dict['capabilities'] = self.capabilities.to_dict()
        # override the default output from pydantic by calling `to_dict()` of content_hints
        if self.content_hints:
            _dict['contentHints'] = self.content_hints.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in content_restrictions (list)
        _items = []
        if self.content_restrictions:
            for _item_content_restrictions in self.content_restrictions:
                if _item_content_restrictions:
                    _items.append(_item_content_restrictions.to_dict())
            _dict['contentRestrictions'] = _items
        # override the default output from pydantic by calling `to_dict()` of image_media_metadata
        if self.image_media_metadata:
            _dict['imageMediaMetadata'] = self.image_media_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of label_info
        if self.label_info:
            _dict['labelInfo'] = self.label_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_modifying_user
        if self.last_modifying_user:
            _dict['lastModifyingUser'] = self.last_modifying_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of link_share_metadata
        if self.link_share_metadata:
            _dict['linkShareMetadata'] = self.link_share_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in owners (list)
        _items = []
        if self.owners:
            for _item_owners in self.owners:
                if _item_owners:
                    _items.append(_item_owners.to_dict())
            _dict['owners'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in permissions (list)
        _items = []
        if self.permissions:
            for _item_permissions in self.permissions:
                if _item_permissions:
                    _items.append(_item_permissions.to_dict())
            _dict['permissions'] = _items
        # override the default output from pydantic by calling `to_dict()` of sharing_user
        if self.sharing_user:
            _dict['sharingUser'] = self.sharing_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of shortcut_details
        if self.shortcut_details:
            _dict['shortcutDetails'] = self.shortcut_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trashing_user
        if self.trashing_user:
            _dict['trashingUser'] = self.trashing_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of video_media_metadata
        if self.video_media_metadata:
            _dict['videoMediaMetadata'] = self.video_media_metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of File from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "appProperties": obj.get("appProperties"),
            "capabilities": FileCapabilities.from_dict(obj["capabilities"]) if obj.get("capabilities") is not None else None,
            "contentHints": FileContentHints.from_dict(obj["contentHints"]) if obj.get("contentHints") is not None else None,
            "contentRestrictions": [ContentRestriction.from_dict(_item) for _item in obj["contentRestrictions"]] if obj.get("contentRestrictions") is not None else None,
            "copyRequiresWriterPermission": obj.get("copyRequiresWriterPermission"),
            "createdTime": obj.get("createdTime"),
            "description": obj.get("description"),
            "driveId": obj.get("driveId"),
            "explicitlyTrashed": obj.get("explicitlyTrashed"),
            "exportLinks": obj.get("exportLinks"),
            "fileExtension": obj.get("fileExtension"),
            "folderColorRgb": obj.get("folderColorRgb"),
            "fullFileExtension": obj.get("fullFileExtension"),
            "hasAugmentedPermissions": obj.get("hasAugmentedPermissions"),
            "hasThumbnail": obj.get("hasThumbnail"),
            "headRevisionId": obj.get("headRevisionId"),
            "iconLink": obj.get("iconLink"),
            "id": obj.get("id"),
            "imageMediaMetadata": FileImageMediaMetadata.from_dict(obj["imageMediaMetadata"]) if obj.get("imageMediaMetadata") is not None else None,
            "isAppAuthorized": obj.get("isAppAuthorized"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'drive#file',
            "labelInfo": FileLabelInfo.from_dict(obj["labelInfo"]) if obj.get("labelInfo") is not None else None,
            "lastModifyingUser": User.from_dict(obj["lastModifyingUser"]) if obj.get("lastModifyingUser") is not None else None,
            "linkShareMetadata": FileLinkShareMetadata.from_dict(obj["linkShareMetadata"]) if obj.get("linkShareMetadata") is not None else None,
            "md5Checksum": obj.get("md5Checksum"),
            "mimeType": obj.get("mimeType"),
            "modifiedByMe": obj.get("modifiedByMe"),
            "modifiedByMeTime": obj.get("modifiedByMeTime"),
            "modifiedTime": obj.get("modifiedTime"),
            "name": obj.get("name"),
            "originalFilename": obj.get("originalFilename"),
            "ownedByMe": obj.get("ownedByMe"),
            "owners": [User.from_dict(_item) for _item in obj["owners"]] if obj.get("owners") is not None else None,
            "parents": obj.get("parents"),
            "permissionIds": obj.get("permissionIds"),
            "permissions": [Permission.from_dict(_item) for _item in obj["permissions"]] if obj.get("permissions") is not None else None,
            "properties": obj.get("properties"),
            "quotaBytesUsed": obj.get("quotaBytesUsed"),
            "resourceKey": obj.get("resourceKey"),
            "sha1Checksum": obj.get("sha1Checksum"),
            "sha256Checksum": obj.get("sha256Checksum"),
            "shared": obj.get("shared"),
            "sharedWithMeTime": obj.get("sharedWithMeTime"),
            "sharingUser": User.from_dict(obj["sharingUser"]) if obj.get("sharingUser") is not None else None,
            "shortcutDetails": FileShortcutDetails.from_dict(obj["shortcutDetails"]) if obj.get("shortcutDetails") is not None else None,
            "size": obj.get("size"),
            "spaces": obj.get("spaces"),
            "starred": obj.get("starred"),
            "teamDriveId": obj.get("teamDriveId"),
            "thumbnailLink": obj.get("thumbnailLink"),
            "thumbnailVersion": obj.get("thumbnailVersion"),
            "trashed": obj.get("trashed"),
            "trashedTime": obj.get("trashedTime"),
            "trashingUser": User.from_dict(obj["trashingUser"]) if obj.get("trashingUser") is not None else None,
            "version": obj.get("version"),
            "videoMediaMetadata": FileVideoMediaMetadata.from_dict(obj["videoMediaMetadata"]) if obj.get("videoMediaMetadata") is not None else None,
            "viewedByMe": obj.get("viewedByMe"),
            "viewedByMeTime": obj.get("viewedByMeTime"),
            "viewersCanCopyContent": obj.get("viewersCanCopyContent"),
            "webContentLink": obj.get("webContentLink"),
            "webViewLink": obj.get("webViewLink"),
            "writersCanShare": obj.get("writersCanShare")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.reply import Reply

class TestReply(unittest.TestCase):
    """Reply unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Reply:
        """Test Reply
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Reply`
        """
        model = Reply()
        if include_optional:
            return Reply(
                action = '',
                author = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', ),
                content = '',
                created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                deleted = True,
                html_content = '',
                id = '',
                kind = 'drive#reply',
                modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return Reply(
        )
        """

    def testReply(self):
        """Test Reply"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.list_operations_response import ListOperationsResponse

class TestListOperationsResponse(unittest.TestCase):
    """ListOperationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListOperationsResponse:
        """Test ListOperationsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListOperationsResponse`
        """
        model = ListOperationsResponse()
        if include_optional:
            return ListOperationsResponse(
                next_page_token = '',
                operations = [
                    google_drive_ti.models.operation.Operation(
                        done = True, 
                        error = google_drive_ti.models.status.Status(
                            code = 56, 
                            details = [
                                None
                                ], 
                            message = '', ), 
                        metadata = google_drive_ti.models.metadata.metadata(), 
                        name = '', 
                        response = google_drive_ti.models.response.response(), )
                    ]
            )
        else:
            return ListOperationsResponse(
        )
        """

    def testListOperationsResponse(self):
        """Test ListOperationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from google_drive_ti.models.file_image_media_metadata_location import FileImageMediaMetadataLocation
from typing import Optional, Set
from typing_extensions import Self

class FileImageMediaMetadata(BaseModel):
    """
    Output only. Additional metadata about image media, if available.
    """ # noqa: E501
    aperture: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Output only. The aperture used to create the photo (f-number).")
    camera_make: Optional[StrictStr] = Field(default=None, description="Output only. The make of the camera used to create the photo.", alias="cameraMake")
    camera_model: Optional[StrictStr] = Field(default=None, description="Output only. The model of the camera used to create the photo.", alias="cameraModel")
    color_space: Optional[StrictStr] = Field(default=None, description="Output only. The color space of the photo.", alias="colorSpace")
    exposure_bias: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Output only. The exposure bias of the photo (APEX value).", alias="exposureBias")
    exposure_mode: Optional[StrictStr] = Field(default=None, description="Output only. The exposure mode used to create the photo.", alias="exposureMode")
    exposure_time: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Output only. The length of the exposure, in seconds.", alias="exposureTime")
    flash_used: Optional[StrictBool] = Field(default=None, description="Output only. Whether a flash was used to create the photo.", alias="flashUsed")
    focal_length: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Output only. The focal length used to create the photo, in millimeters.", alias="focalLength")
    height: Optional[StrictInt] = Field(default=None, description="Output only. The height of the image in pixels.")
    iso_speed: Optional[StrictInt] = Field(default=None, description="Output only. The ISO speed used to create the photo.", alias="isoSpeed")
    lens: Optional[StrictStr] = Field(default=None, description="Output only. The lens used to create the photo.")
    location: Optional[FileImageMediaMetadataLocation] = None
    max_aperture_value: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Output only. The smallest f-number of the lens at the focal length used to create the photo (APEX value).", alias="maxApertureValue")
    metering_mode: Optional[StrictStr] = Field(default=None, description="Output only. The metering mode used to create the photo.", alias="meteringMode")
    rotation: Optional[StrictInt] = Field(default=None, description="Output only. The number of clockwise 90 degree rotations applied from the image's original orientation.")
    sensor: Optional[StrictStr] = Field(default=None, description="Output only. The type of sensor used to create the photo.")
    subject_distance: Optional[StrictInt] = Field(default=None, description="Output only. The distance to the subject of the photo, in meters.", alias="subjectDistance")
    time: Optional[StrictStr] = Field(default=None, description="Output only. The date and time the photo was taken (EXIF DateTime).")
    white_balance: Optional[StrictStr] = Field(default=None, description="Output only. The white balance mode used to create the photo.", alias="whiteBalance")
    width: Optional[StrictInt] = Field(default=None, description="Output only. The width of the image in pixels.")
    __properties: ClassVar[List[str]] = ["aperture", "cameraMake", "cameraModel", "colorSpace", "exposureBias", "exposureMode", "exposureTime", "flashUsed", "focalLength", "height", "isoSpeed", "lens", "location", "maxApertureValue", "meteringMode", "rotation", "sensor", "subjectDistance", "time", "whiteBalance", "width"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FileImageMediaMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FileImageMediaMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aperture": obj.get("aperture"),
            "cameraMake": obj.get("cameraMake"),
            "cameraModel": obj.get("cameraModel"),
            "colorSpace": obj.get("colorSpace"),
            "exposureBias": obj.get("exposureBias"),
            "exposureMode": obj.get("exposureMode"),
            "exposureTime": obj.get("exposureTime"),
            "flashUsed": obj.get("flashUsed"),
            "focalLength": obj.get("focalLength"),
            "height": obj.get("height"),
            "isoSpeed": obj.get("isoSpeed"),
            "lens": obj.get("lens"),
            "location": FileImageMediaMetadataLocation.from_dict(obj["location"]) if obj.get("location") is not None else None,
            "maxApertureValue": obj.get("maxApertureValue"),
            "meteringMode": obj.get("meteringMode"),
            "rotation": obj.get("rotation"),
            "sensor": obj.get("sensor"),
            "subjectDistance": obj.get("subjectDistance"),
            "time": obj.get("time"),
            "whiteBalance": obj.get("whiteBalance"),
            "width": obj.get("width")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LabelFieldModification(BaseModel):
    """
    A modification to a label's field.
    """ # noqa: E501
    field_id: Optional[StrictStr] = Field(default=None, description="The ID of the field to be modified.", alias="fieldId")
    kind: Optional[StrictStr] = Field(default=None, description="This is always drive#labelFieldModification.")
    set_date_values: Optional[List[date]] = Field(default=None, description="Replaces the value of a dateString Field with these new values. The string must be in the RFC 3339 full-date format: YYYY-MM-DD.", alias="setDateValues")
    set_integer_values: Optional[List[StrictStr]] = Field(default=None, description="Replaces the value of an `integer` field with these new values.", alias="setIntegerValues")
    set_selection_values: Optional[List[StrictStr]] = Field(default=None, description="Replaces a `selection` field with these new values.", alias="setSelectionValues")
    set_text_values: Optional[List[StrictStr]] = Field(default=None, description="Sets the value of a `text` field.", alias="setTextValues")
    set_user_values: Optional[List[StrictStr]] = Field(default=None, description="Replaces a `user` field with these new values. The values must be valid email addresses.", alias="setUserValues")
    unset_values: Optional[StrictBool] = Field(default=None, description="Unsets the values for this field.", alias="unsetValues")
    __properties: ClassVar[List[str]] = ["fieldId", "kind", "setDateValues", "setIntegerValues", "setSelectionValues", "setTextValues", "setUserValues", "unsetValues"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LabelFieldModification from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LabelFieldModification from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "fieldId": obj.get("fieldId"),
            "kind": obj.get("kind"),
            "setDateValues": obj.get("setDateValues"),
            "setIntegerValues": obj.get("setIntegerValues"),
            "setSelectionValues": obj.get("setSelectionValues"),
            "setTextValues": obj.get("setTextValues"),
            "setUserValues": obj.get("setUserValues"),
            "unsetValues": obj.get("unsetValues")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.operation import Operation

class TestOperation(unittest.TestCase):
    """Operation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Operation:
        """Test Operation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Operation`
        """
        model = Operation()
        if include_optional:
            return Operation(
                done = True,
                error = google_drive_ti.models.status.Status(
                    code = 56, 
                    details = [
                        None
                        ], 
                    message = '', ),
                metadata = google_drive_ti.models.metadata.metadata(),
                name = '',
                response = google_drive_ti.models.response.response()
            )
        else:
            return Operation(
        )
        """

    def testOperation(self):
        """Test Operation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from google_drive_ti.models.revision import Revision
from google_drive_ti.models.revision_list import RevisionList

from google_drive_ti.api_client import ApiClient, RequestSerialized
from google_drive_ti.api_response import ApiResponse
from google_drive_ti.rest import RESTResponseType


class RevisionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def drive_revisions_delete(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> None:
        """drive_revisions_delete

        Permanently deletes a file version. You can only delete revisions for files with binary content in Google Drive, like images or videos. Revisions for other files, like Google Docs or Sheets, and the last remaining file version can't be deleted.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_delete_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def drive_revisions_delete_with_http_info(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[None]:
        """drive_revisions_delete

        Permanently deletes a file version. You can only delete revisions for files with binary content in Google Drive, like images or videos. Revisions for other files, like Google Docs or Sheets, and the last remaining file version can't be deleted.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_delete_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def drive_revisions_delete_without_preload_content(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """drive_revisions_delete

        Permanently deletes a file version. You can only delete revisions for files with binary content in Google Drive, like images or videos. Revisions for other files, like Google Docs or Sheets, and the last remaining file version can't be deleted.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_delete_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _drive_revisions_delete_serialize(
        self,
        file_id,
        revision_id,
        access_token,
        alt,
        param_callback,
        fields,
        key,
        oauth_token,
        pretty_print,
        quota_user,
        upload_protocol,
        upload_type,
        xgafv,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_id is not None:
            _path_params['fileId'] = file_id
        if revision_id is not None:
            _path_params['revisionId'] = revision_id
        # process the query parameters
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/files/{fileId}/revisions/{revisionId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def drive_revisions_get(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        acknowledge_abuse: Annotated[Optional[StrictBool], Field(description="Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when the `alt` parameter is set to `media` and the user is the owner of the file or an organizer of the shared drive in which the file resides.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> Revision:
        """drive_revisions_get

        Gets a revision's metadata or content by ID.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param acknowledge_abuse: Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when the `alt` parameter is set to `media` and the user is the owner of the file or an organizer of the shared drive in which the file resides.
        :type acknowledge_abuse: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_get_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            acknowledge_abuse=acknowledge_abuse,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Revision",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def drive_revisions_get_with_http_info(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        acknowledge_abuse: Annotated[Optional[StrictBool], Field(description="Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when the `alt` parameter is set to `media` and the user is the owner of the file or an organizer of the shared drive in which the file resides.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[Revision]:
        """drive_revisions_get

        Gets a revision's metadata or content by ID.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param acknowledge_abuse: Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when the `alt` parameter is set to `media` and the user is the owner of the file or an organizer of the shared drive in which the file resides.
        :type acknowledge_abuse: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_get_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            acknowledge_abuse=acknowledge_abuse,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Revision",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def drive_revisions_get_without_preload_content(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        acknowledge_abuse: Annotated[Optional[StrictBool], Field(description="Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when the `alt` parameter is set to `media` and the user is the owner of the file or an organizer of the shared drive in which the file resides.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """drive_revisions_get

        Gets a revision's metadata or content by ID.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param acknowledge_abuse: Whether the user is acknowledging the risk of downloading known malware or other abusive files. This is only applicable when the `alt` parameter is set to `media` and the user is the owner of the file or an organizer of the shared drive in which the file resides.
        :type acknowledge_abuse: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_get_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            acknowledge_abuse=acknowledge_abuse,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Revision",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _drive_revisions_get_serialize(
        self,
        file_id,
        revision_id,
        access_token,
        alt,
        param_callback,
        fields,
        key,
        oauth_token,
        pretty_print,
        quota_user,
        upload_protocol,
        upload_type,
        xgafv,
        acknowledge_abuse,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_id is not None:
            _path_params['fileId'] = file_id
        if revision_id is not None:
            _path_params['revisionId'] = revision_id
        # process the query parameters
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if acknowledge_abuse is not None:
            
            _query_params.append(('acknowledgeAbuse', acknowledge_abuse))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/files/{fileId}/revisions/{revisionId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def drive_revisions_list(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The maximum number of revisions to return per page.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RevisionList:
        """drive_revisions_list

        Lists a file's revisions.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param page_size: The maximum number of revisions to return per page.
        :type page_size: int
        :param page_token: The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.
        :type page_token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_list_serialize(
            file_id=file_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            page_size=page_size,
            page_token=page_token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RevisionList",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def drive_revisions_list_with_http_info(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The maximum number of revisions to return per page.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[RevisionList]:
        """drive_revisions_list

        Lists a file's revisions.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param page_size: The maximum number of revisions to return per page.
        :type page_size: int
        :param page_token: The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.
        :type page_token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_list_serialize(
            file_id=file_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            page_size=page_size,
            page_token=page_token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RevisionList",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def drive_revisions_list_without_preload_content(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The maximum number of revisions to return per page.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """drive_revisions_list

        Lists a file's revisions.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param page_size: The maximum number of revisions to return per page.
        :type page_size: int
        :param page_token: The token for continuing a previous list request on the next page. This should be set to the value of 'nextPageToken' from the previous response.
        :type page_token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_list_serialize(
            file_id=file_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            page_size=page_size,
            page_token=page_token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "RevisionList",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _drive_revisions_list_serialize(
        self,
        file_id,
        access_token,
        alt,
        param_callback,
        fields,
        key,
        oauth_token,
        pretty_print,
        quota_user,
        upload_protocol,
        upload_type,
        xgafv,
        page_size,
        page_token,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_id is not None:
            _path_params['fileId'] = file_id
        # process the query parameters
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page_token is not None:
            
            _query_params.append(('pageToken', page_token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/files/{fileId}/revisions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def drive_revisions_update(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        revision: Optional[Revision] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> Revision:
        """drive_revisions_update

        Updates a revision with patch semantics.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param revision:
        :type revision: Revision
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_update_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            revision=revision,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Revision",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def drive_revisions_update_with_http_info(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        revision: Optional[Revision] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[Revision]:
        """drive_revisions_update

        Updates a revision with patch semantics.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param revision:
        :type revision: Revision
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_update_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            revision=revision,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Revision",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def drive_revisions_update_without_preload_content(
        self,
        file_id: Annotated[StrictStr, Field(description="The ID of the file.")],
        revision_id: Annotated[StrictStr, Field(description="The ID of the revision.")],
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        revision: Optional[Revision] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """drive_revisions_update

        Updates a revision with patch semantics.

        :param file_id: The ID of the file. (required)
        :type file_id: str
        :param revision_id: The ID of the revision. (required)
        :type revision_id: str
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param revision:
        :type revision: Revision
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._drive_revisions_update_serialize(
            file_id=file_id,
            revision_id=revision_id,
            access_token=access_token,
            alt=alt,
            param_callback=param_callback,
            fields=fields,
            key=key,
            oauth_token=oauth_token,
            pretty_print=pretty_print,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            upload_type=upload_type,
            xgafv=xgafv,
            revision=revision,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Revision",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _drive_revisions_update_serialize(
        self,
        file_id,
        revision_id,
        access_token,
        alt,
        param_callback,
        fields,
        key,
        oauth_token,
        pretty_print,
        quota_user,
        upload_protocol,
        upload_type,
        xgafv,
        revision,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if file_id is not None:
            _path_params['fileId'] = file_id
        if revision_id is not None:
            _path_params['revisionId'] = revision_id
        # process the query parameters
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if revision is not None:
            _body_params = revision


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/files/{fileId}/revisions/{revisionId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Channel(BaseModel):
    """
    A notification channel used to watch for resource changes.
    """ # noqa: E501
    address: Optional[StrictStr] = Field(default=None, description="The address where notifications are delivered for this channel.")
    expiration: Optional[StrictStr] = Field(default=None, description="Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds. Optional.")
    id: Optional[StrictStr] = Field(default=None, description="A UUID or similar unique string that identifies this channel.")
    kind: Optional[StrictStr] = Field(default='api#channel', description="Identifies this as a notification channel used to watch for changes to a resource, which is `api#channel`.")
    params: Optional[Dict[str, Any]] = Field(default=None, description="Additional parameters controlling delivery channel behavior. Optional.")
    payload: Optional[StrictBool] = Field(default=None, description="A Boolean value to indicate whether payload is wanted. Optional.")
    resource_id: Optional[StrictStr] = Field(default=None, description="An opaque ID that identifies the resource being watched on this channel. Stable across different API versions.", alias="resourceId")
    resource_uri: Optional[StrictStr] = Field(default=None, description="A version-specific identifier for the watched resource.", alias="resourceUri")
    token: Optional[StrictStr] = Field(default=None, description="An arbitrary string delivered to the target address with each notification delivered over this channel. Optional.")
    type: Optional[StrictStr] = Field(default=None, description="The type of delivery mechanism used for this channel. Valid values are \"web_hook\" or \"webhook\".")
    __properties: ClassVar[List[str]] = ["address", "expiration", "id", "kind", "params", "payload", "resourceId", "resourceUri", "token", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Channel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Channel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "address": obj.get("address"),
            "expiration": obj.get("expiration"),
            "id": obj.get("id"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'api#channel',
            "params": obj.get("params"),
            "payload": obj.get("payload"),
            "resourceId": obj.get("resourceId"),
            "resourceUri": obj.get("resourceUri"),
            "token": obj.get("token"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_list import FileList

class TestFileList(unittest.TestCase):
    """FileList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileList:
        """Test FileList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileList`
        """
        model = FileList()
        if include_optional:
            return FileList(
                files = [
                    google_drive_ti.models.file.File(
                        app_properties = google_drive_ti.models.app_properties.appProperties(), 
                        capabilities = google_drive_ti.models.file_capabilities.File_capabilities(
                            can_accept_ownership = True, 
                            can_add_children = True, 
                            can_add_folder_from_another_drive = True, 
                            can_add_my_drive_parent = True, 
                            can_change_copy_requires_writer_permission = True, 
                            can_change_security_update_enabled = True, 
                            can_change_viewers_can_copy_content = True, 
                            can_comment = True, 
                            can_copy = True, 
                            can_delete = True, 
                            can_delete_children = True, 
                            can_download = True, 
                            can_edit = True, 
                            can_list_children = True, 
                            can_modify_content = True, 
                            can_modify_content_restriction = True, 
                            can_modify_editor_content_restriction = True, 
                            can_modify_labels = True, 
                            can_modify_owner_content_restriction = True, 
                            can_move_children_out_of_drive = True, 
                            can_move_children_out_of_team_drive = True, 
                            can_move_children_within_drive = True, 
                            can_move_children_within_team_drive = True, 
                            can_move_item_into_team_drive = True, 
                            can_move_item_out_of_drive = True, 
                            can_move_item_out_of_team_drive = True, 
                            can_move_item_within_drive = True, 
                            can_move_item_within_team_drive = True, 
                            can_move_team_drive_item = True, 
                            can_read_drive = True, 
                            can_read_labels = True, 
                            can_read_revisions = True, 
                            can_read_team_drive = True, 
                            can_remove_children = True, 
                            can_remove_content_restriction = True, 
                            can_remove_my_drive_parent = True, 
                            can_rename = True, 
                            can_share = True, 
                            can_trash = True, 
                            can_trash_children = True, 
                            can_untrash = True, ), 
                        content_hints = google_drive_ti.models.file_content_hints.File_contentHints(
                            indexable_text = '', 
                            thumbnail = google_drive_ti.models.file_content_hints_thumbnail.File_contentHints_thumbnail(
                                image = 'YQ==', 
                                mime_type = '', ), ), 
                        content_restrictions = [
                            google_drive_ti.models.content_restriction.ContentRestriction(
                                owner_restricted = True, 
                                read_only = True, 
                                reason = '', 
                                restricting_user = google_drive_ti.models.user.User(
                                    display_name = '', 
                                    email_address = '', 
                                    kind = 'drive#user', 
                                    me = True, 
                                    permission_id = '', 
                                    photo_link = '', ), 
                                restriction_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                system_restricted = True, 
                                type = '', )
                            ], 
                        copy_requires_writer_permission = True, 
                        created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        drive_id = '', 
                        explicitly_trashed = True, 
                        export_links = google_drive_ti.models.export_links.exportLinks(), 
                        file_extension = '', 
                        folder_color_rgb = '', 
                        full_file_extension = '', 
                        has_augmented_permissions = True, 
                        has_thumbnail = True, 
                        head_revision_id = '', 
                        icon_link = '', 
                        id = '', 
                        image_media_metadata = google_drive_ti.models.file_image_media_metadata.File_imageMediaMetadata(
                            aperture = 1.337, 
                            camera_make = '', 
                            camera_model = '', 
                            color_space = '', 
                            exposure_bias = 1.337, 
                            exposure_mode = '', 
                            exposure_time = 1.337, 
                            flash_used = True, 
                            focal_length = 1.337, 
                            height = 56, 
                            iso_speed = 56, 
                            lens = '', 
                            location = google_drive_ti.models.file_image_media_metadata_location.File_imageMediaMetadata_location(
                                altitude = 1.337, 
                                latitude = 1.337, 
                                longitude = 1.337, ), 
                            max_aperture_value = 1.337, 
                            metering_mode = '', 
                            rotation = 56, 
                            sensor = '', 
                            subject_distance = 56, 
                            time = '', 
                            white_balance = '', 
                            width = 56, ), 
                        is_app_authorized = True, 
                        kind = 'drive#file', 
                        label_info = google_drive_ti.models.file_label_info.File_labelInfo(
                            labels = [
                                google_drive_ti.models.label.Label(
                                    fields = google_drive_ti.models.fields.fields(), 
                                    id = '', 
                                    kind = '', 
                                    revision_id = '', )
                                ], ), 
                        last_modifying_user = google_drive_ti.models.user.User(
                            display_name = '', 
                            email_address = '', 
                            kind = 'drive#user', 
                            me = True, 
                            permission_id = '', 
                            photo_link = '', ), 
                        link_share_metadata = google_drive_ti.models.file_link_share_metadata.File_linkShareMetadata(
                            security_update_eligible = True, 
                            security_update_enabled = True, ), 
                        md5_checksum = '', 
                        mime_type = '', 
                        modified_by_me = True, 
                        modified_by_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        original_filename = '', 
                        owned_by_me = True, 
                        owners = [
                            
                            ], 
                        parents = [
                            ''
                            ], 
                        permission_ids = [
                            ''
                            ], 
                        permissions = [
                            google_drive_ti.models.permission.Permission(
                                allow_file_discovery = True, 
                                deleted = True, 
                                display_name = '', 
                                domain = '', 
                                email_address = '', 
                                expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                kind = 'drive#permission', 
                                pending_owner = True, 
                                permission_details = [
                                    google_drive_ti.models.permission_permission_details_inner.Permission_permissionDetails_inner(
                                        inherited = True, 
                                        inherited_from = '', 
                                        permission_type = '', 
                                        role = '', )
                                    ], 
                                photo_link = '', 
                                role = '', 
                                team_drive_permission_details = [
                                    google_drive_ti.models.permission_team_drive_permission_details_inner.Permission_teamDrivePermissionDetails_inner(
                                        inherited = True, 
                                        inherited_from = '', 
                                        role = '', 
                                        team_drive_permission_type = '', )
                                    ], 
                                type = '', 
                                view = '', )
                            ], 
                        properties = google_drive_ti.models.properties.properties(), 
                        quota_bytes_used = '', 
                        resource_key = '', 
                        sha1_checksum = '', 
                        sha256_checksum = '', 
                        shared = True, 
                        shared_with_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        sharing_user = , 
                        shortcut_details = google_drive_ti.models.file_shortcut_details.File_shortcutDetails(
                            target_id = '', 
                            target_mime_type = '', 
                            target_resource_key = '', ), 
                        size = '', 
                        spaces = [
                            ''
                            ], 
                        starred = True, 
                        team_drive_id = '', 
                        thumbnail_link = '', 
                        thumbnail_version = '', 
                        trashed = True, 
                        trashed_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        trashing_user = , 
                        version = '', 
                        video_media_metadata = google_drive_ti.models.file_video_media_metadata.File_videoMediaMetadata(
                            duration_millis = '', 
                            height = 56, 
                            width = 56, ), 
                        viewed_by_me = True, 
                        viewed_by_me_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        viewers_can_copy_content = True, 
                        web_content_link = '', 
                        web_view_link = '', 
                        writers_can_share = True, )
                    ],
                incomplete_search = True,
                kind = 'drive#fileList',
                next_page_token = ''
            )
        else:
            return FileList(
        )
        """

    def testFileList(self):
        """Test FileList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.permission_list import PermissionList

class TestPermissionList(unittest.TestCase):
    """PermissionList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PermissionList:
        """Test PermissionList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PermissionList`
        """
        model = PermissionList()
        if include_optional:
            return PermissionList(
                kind = 'drive#permissionList',
                next_page_token = '',
                permissions = [
                    google_drive_ti.models.permission.Permission(
                        allow_file_discovery = True, 
                        deleted = True, 
                        display_name = '', 
                        domain = '', 
                        email_address = '', 
                        expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        kind = 'drive#permission', 
                        pending_owner = True, 
                        permission_details = [
                            google_drive_ti.models.permission_permission_details_inner.Permission_permissionDetails_inner(
                                inherited = True, 
                                inherited_from = '', 
                                permission_type = '', 
                                role = '', )
                            ], 
                        photo_link = '', 
                        role = '', 
                        team_drive_permission_details = [
                            google_drive_ti.models.permission_team_drive_permission_details_inner.Permission_teamDrivePermissionDetails_inner(
                                inherited = True, 
                                inherited_from = '', 
                                role = '', 
                                team_drive_permission_type = '', )
                            ], 
                        type = '', 
                        view = '', )
                    ]
            )
        else:
            return PermissionList(
        )
        """

    def testPermissionList(self):
        """Test PermissionList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.modify_labels_request import ModifyLabelsRequest

class TestModifyLabelsRequest(unittest.TestCase):
    """ModifyLabelsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ModifyLabelsRequest:
        """Test ModifyLabelsRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ModifyLabelsRequest`
        """
        model = ModifyLabelsRequest()
        if include_optional:
            return ModifyLabelsRequest(
                kind = '',
                label_modifications = [
                    google_drive_ti.models.label_modification.LabelModification(
                        field_modifications = [
                            google_drive_ti.models.label_field_modification.LabelFieldModification(
                                field_id = '', 
                                kind = '', 
                                set_date_values = [
                                    datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date()
                                    ], 
                                set_integer_values = [
                                    ''
                                    ], 
                                set_selection_values = [
                                    ''
                                    ], 
                                set_text_values = [
                                    ''
                                    ], 
                                set_user_values = [
                                    ''
                                    ], 
                                unset_values = True, )
                            ], 
                        kind = '', 
                        label_id = '', 
                        remove_label = True, )
                    ]
            )
        else:
            return ModifyLabelsRequest(
        )
        """

    def testModifyLabelsRequest(self):
        """Test ModifyLabelsRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.comment import Comment

class TestComment(unittest.TestCase):
    """Comment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Comment:
        """Test Comment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Comment`
        """
        model = Comment()
        if include_optional:
            return Comment(
                anchor = '',
                author = google_drive_ti.models.user.User(
                    display_name = '', 
                    email_address = '', 
                    kind = 'drive#user', 
                    me = True, 
                    permission_id = '', 
                    photo_link = '', ),
                content = '',
                created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                deleted = True,
                html_content = '',
                id = '',
                kind = 'drive#comment',
                modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                quoted_file_content = google_drive_ti.models.comment_quoted_file_content.Comment_quotedFileContent(
                    mime_type = '', 
                    value = '', ),
                replies = [
                    google_drive_ti.models.reply.Reply(
                        action = '', 
                        author = google_drive_ti.models.user.User(
                            display_name = '', 
                            email_address = '', 
                            kind = 'drive#user', 
                            me = True, 
                            permission_id = '', 
                            photo_link = '', ), 
                        content = '', 
                        created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        deleted = True, 
                        html_content = '', 
                        id = '', 
                        kind = 'drive#reply', 
                        modified_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                resolved = True
            )
        else:
            return Comment(
        )
        """

    def testComment(self):
        """Test Comment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_image_media_metadata import FileImageMediaMetadata

class TestFileImageMediaMetadata(unittest.TestCase):
    """FileImageMediaMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileImageMediaMetadata:
        """Test FileImageMediaMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileImageMediaMetadata`
        """
        model = FileImageMediaMetadata()
        if include_optional:
            return FileImageMediaMetadata(
                aperture = 1.337,
                camera_make = '',
                camera_model = '',
                color_space = '',
                exposure_bias = 1.337,
                exposure_mode = '',
                exposure_time = 1.337,
                flash_used = True,
                focal_length = 1.337,
                height = 56,
                iso_speed = 56,
                lens = '',
                location = google_drive_ti.models.file_image_media_metadata_location.File_imageMediaMetadata_location(
                    altitude = 1.337, 
                    latitude = 1.337, 
                    longitude = 1.337, ),
                max_aperture_value = 1.337,
                metering_mode = '',
                rotation = 56,
                sensor = '',
                subject_distance = 56,
                time = '',
                white_balance = '',
                width = 56
            )
        else:
            return FileImageMediaMetadata(
        )
        """

    def testFileImageMediaMetadata(self):
        """Test FileImageMediaMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.file_video_media_metadata import FileVideoMediaMetadata

class TestFileVideoMediaMetadata(unittest.TestCase):
    """FileVideoMediaMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileVideoMediaMetadata:
        """Test FileVideoMediaMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileVideoMediaMetadata`
        """
        model = FileVideoMediaMetadata()
        if include_optional:
            return FileVideoMediaMetadata(
                duration_millis = '',
                height = 56,
                width = 56
            )
        else:
            return FileVideoMediaMetadata(
        )
        """

    def testFileVideoMediaMetadata(self):
        """Test FileVideoMediaMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.api.files_api import FilesApi


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesApi()

    def tearDown(self) -> None:
        pass

    def test_drive_files_copy(self) -> None:
        """Test case for drive_files_copy

        """
        pass

    def test_drive_files_create(self) -> None:
        """Test case for drive_files_create

        """
        pass

    def test_drive_files_delete(self) -> None:
        """Test case for drive_files_delete

        """
        pass

    def test_drive_files_download(self) -> None:
        """Test case for drive_files_download

        """
        pass

    def test_drive_files_empty_trash(self) -> None:
        """Test case for drive_files_empty_trash

        """
        pass

    def test_drive_files_export(self) -> None:
        """Test case for drive_files_export

        """
        pass

    def test_drive_files_generate_ids(self) -> None:
        """Test case for drive_files_generate_ids

        """
        pass

    def test_drive_files_get(self) -> None:
        """Test case for drive_files_get

        """
        pass

    def test_drive_files_list(self) -> None:
        """Test case for drive_files_list

        """
        pass

    def test_drive_files_list_labels(self) -> None:
        """Test case for drive_files_list_labels

        """
        pass

    def test_drive_files_modify_labels(self) -> None:
        """Test case for drive_files_modify_labels

        """
        pass

    def test_drive_files_update(self) -> None:
        """Test case for drive_files_update

        """
        pass

    def test_drive_files_watch(self) -> None:
        """Test case for drive_files_watch

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Google Drive API

    The Google Drive API allows clients to access resources from Google Drive.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from google_drive_ti.models.team_drive import TeamDrive

class TestTeamDrive(unittest.TestCase):
    """TeamDrive unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TeamDrive:
        """Test TeamDrive
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TeamDrive`
        """
        model = TeamDrive()
        if include_optional:
            return TeamDrive(
                background_image_file = google_drive_ti.models.team_drive_background_image_file.TeamDrive_backgroundImageFile(
                    id = '', 
                    width = 1.337, 
                    x_coordinate = 1.337, 
                    y_coordinate = 1.337, ),
                background_image_link = '',
                capabilities = google_drive_ti.models.team_drive_capabilities.TeamDrive_capabilities(
                    can_add_children = True, 
                    can_change_copy_requires_writer_permission_restriction = True, 
                    can_change_domain_users_only_restriction = True, 
                    can_change_sharing_folders_requires_organizer_permission_restriction = True, 
                    can_change_team_drive_background = True, 
                    can_change_team_members_only_restriction = True, 
                    can_comment = True, 
                    can_copy = True, 
                    can_delete_children = True, 
                    can_delete_team_drive = True, 
                    can_download = True, 
                    can_edit = True, 
                    can_list_children = True, 
                    can_manage_members = True, 
                    can_read_revisions = True, 
                    can_remove_children = True, 
                    can_rename = True, 
                    can_rename_team_drive = True, 
                    can_reset_team_drive_restrictions = True, 
                    can_share = True, 
                    can_trash_children = True, ),
                color_rgb = '',
                created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                kind = 'drive#teamDrive',
                name = '',
                org_unit_id = '',
                restrictions = google_drive_ti.models.team_drive_restrictions.TeamDrive_restrictions(
                    admin_managed_restrictions = True, 
                    copy_requires_writer_permission = True, 
                    domain_users_only = True, 
                    sharing_folders_requires_organizer_permission = True, 
                    team_members_only = True, ),
                theme_id = ''
            )
        else:
            return TeamDrive(
        )
        """

    def testTeamDrive(self):
        """Test TeamDrive"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
